@@ -14,8 +14,8 @@ use strict;
 #     chmod u+x lightwatch
 #
 
-$ENV{'PATH'} = '/bin:/usr/bin:/usr/local/bin';
 delete @ENV{'IFS', 'CDPATH', 'ENV', 'BASH_ENV'};
+$ENV{'PATH'} = '/bin:/usr/bin:/usr/local/bin:/sbin:/usr/sbin:/usr/local/sbin';
 
 $<=0;  # become root not just effective root
 
